@@ -1,3 +1,10 @@
+# coding=utf-8
+# Filename: core.py
+# pylint: disable=locally-disabled
+"""
+The core of the KM3Pipe framework.
+
+"""
 from __future__ import division, absolute_import, print_function
 
 __author__ = 'tamasgal'
@@ -6,7 +13,7 @@ __author__ = 'tamasgal'
 import logging
 from km3pipe.logger import get_logger
 
-log = get_logger(__name__, logging.INFO)
+log = get_logger(__name__, logging.INFO)  # pylint: disable=C0103
 
 
 class Pipeline(object):
@@ -24,7 +31,15 @@ class Pipeline(object):
         self.modules.append(module_class(name=name, **kwargs))
 
     def drain(self):
-        """Activate the pump and let the flow go"""
+        """Activate the pump and let the flow go.
+
+        This will call the process() method on each attached module until
+        a StopIteration is raised, usually by a pump when it reached the EOF.
+
+        A StopIteration is also raised when self.cycles was set and the
+        number of cycles has reached that limit.
+
+        """
         try:
             while True:
                 self.cycle_count += 1
@@ -39,6 +54,7 @@ class Pipeline(object):
         self.finish()
 
     def finish(self):
+        """Call finish() on each attached module"""
         for module in self.modules:
             log.info("Finishing {0}".format(module.name))
             module.pre_finish()
@@ -57,7 +73,7 @@ class Module(object):
         """The name of the module"""
         return self._name
 
-    def add(self, name, value, help_text):
+    def add(self, name, value):
         """Add the parameter with the desired value to the dict"""
         self.parameters[name] = value
 
@@ -65,14 +81,16 @@ class Module(object):
         """Return the value of the requested parameter"""
         return self.parameters.get(name)
 
-    def process(self, blob):
+    def process(self, blob):  # pylint: disable=R0201
         """Knead the blob and return it"""
         return blob
 
     def finish(self):
+        """Clean everything up."""
         pass
 
     def pre_finish(self):
+        """Do the last few things before calling finish()"""
         self.finish()
 
 
@@ -90,8 +108,8 @@ class Pump(Module):
         except TypeError:
             log.error("Please specify a valid filename.")
             raise SystemExit
-        except IOError as e:
-            log.error(e)
+        except IOError as error_message:
+            log.error(error_message)
             raise SystemExit
 
     def rewind_file(self):
